#--
# Copyright (c) 2009-2010 Novell, Inc.
# 
# All Rights Reserved.
# 
# This program is free software; you can redistribute it and/or modify it
# under the terms of version 2 of the GNU General Public License
# as published by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, contact Novell, Inc.
# 
# To contact Novell about this file by physical or electronic mail,
# you may find current contact information at www.novell.com
#++

#
# patch_test.rb
#
# Test 'Patch' model
#
#

require File.expand_path(File.dirname(__FILE__) + "/../test_helper")
require File.join(File.dirname(__FILE__), "..", "packagekit_stub")
require 'patch'

def read_test_data(name)
  File.readlines File.join(File.dirname(__FILE__), "data", name)
end

class PatchTest < ActiveSupport::TestCase

  def setup
    #
    # Patch model stubbing
    #
    
    @pk_stub = PackageKitStub.new
    @transaction, @packagekit = PackageKit.connect
    
    # avoid accessing the rpm db
    Patch.stubs(:mtime).returns(Time.now)

    Patch.stubs(:open_subprocess).returns(nil)

  end
  
  def test_available_patches

#    @transaction.stubs(:GetUpdates).with("NONE").returns(true)

    # Available updates in PackageKit format
    #
    # Format:
    # [ line1, line2, line3 ]
    # line1: <kind>
    # line2: <name>;<id>;<arch>;<repo>
    # line3: <summary>
    #
    rset = PackageKitResultSet.new "Package", :info => :s, :id => :s, :summary => :s
    rset << [ 'important', 'update-test-affects-package-manager;847;noarch;updates-test', 'update-test: Test updates for 11.2' ]
    rset << [ 'security', 'update-test;844;noarch;updates-test', 'update-test: Test update for 11.2' ]
    @pk_stub.result = rset

    # Mock 'GetUpdates' by defining it
    m = DBus::Method.new("GetUpdates")
    m.from_prototype("in kind:s")
    @transaction.methods[m.name] = m
    class <<@transaction
      def GetUpdates kind
	# dummy !
      end
    end

    # search all patches
    patches = Patch.find(:available)
    assert_equal 2, patches.size
    patch = patches.first
    assert_equal "847", patch.version

    # search one patch
    patch = Patch.find("update-test-affects-package-manager;847;noarch;updates-test")
    assert_equal "847", patch.version

    # search non-existing patch
    patch = Patch.find('888')
    assert_equal [], patch
  end

  def test_patch_install
    rset = PackageKitResultSet.new "Package", :info => :s, :id => :s, :summary => :s
    rset << [ 'important', 'update-test-affects-package-manager;847;noarch;updates-test', 'update-test: Test updates for 11.2' ]
    rset << [ 'security', 'update-test;844;noarch;updates-test', 'update-test: Test update for 11.2' ]
    @pk_stub.result = rset

    # Mock 'GetUpdates' by defining it
    m = DBus::Method.new("GetUpdates")
    m.from_prototype("in kind:s")
    @transaction.methods[m.name] = m

    m2 = DBus::Method.new("UpdatePackages")
    m2.from_prototype("in kind:as")
    @transaction.methods[m2.name] = m2

    class <<@transaction
      def GetUpdates kind
	# dummy !
      end
      def UpdatePackages p_id
	# dummy !
      end
    end

    # install a patch
    patch = Patch.find("update-test-affects-package-manager;847;noarch;updates-test")
    assert patch.install

  end
end
